/**
 * Build a sitemap.
 *
 * @param {Array<string|Entry>} [data] URLs to build a sitemap for.
 * @returns {Root}
 */
export function sitemap(data?: Array<string | Entry>): Root
/**
 * @param {Date|string|number} value
 * @returns {Date}
 */
export function toDate(value: Date | string | number): Date
export type Root = import('xast').Root
export type Element = import('xast').Element
export type Alternate = string | Omit<Entry, 'lang' | 'alternate'>
/**
 * Entries represent a single URL and describe them with metadata.
 */
export type Entry = {
  /**
   * Full URL (example: `'https://example.org/'`). See <https://www.sitemaps.org/protocol.html#locdef>
   */
  url: string
  /**
   * Value indicating when the page last changed.
   */
  modified?: number | string | Date
  /**
   * BCP 47 tag indicating the language of the page (example: `'en-GB'`). See <https://github.com/wooorm/bcp-47>
   */
  lang?: string
  /**
   * Translations of the page, where each key is a BCP 47 tag and each value an entry. Alternate resources inherit fields from the entry they are described in.
   */
  alternate?: {
    [x: string]: Alternate
  }
}
